import logging

import typing
import attr
import cattr

import math
from functools import reduce


# create logger
module_logger = logging.getLogger(__name__)
module_logger.setLevel(logging.DEBUG)


def add_attr_description(attrib, description=None):
    attrib.metadata['__description'] = description
    return attrib

def get_attr_description(cls, attr_name):
    meta = attr.fields_dict(cls)[attr_name]
    return meta.metadata['__description']




# -*- coding: utf-8 -*-

# Learn more: https://github.com/kennethreitz/setup.py

from setuptools import setup, find_packages


with open('README.md') as f:
    readme = f.read()

with open('LICENSE') as f:
    license = f.read()

setup(
    name='attr-descriptions',
    version='0.1.1',
    description='A mini-module that helps to add descriptions to attrs attributes.',
    long_description=readme,
    author='Deniz Bozyigit',
    author_email='deniz195@gmail.com',
    url='https://github.com/deniz195/attr-descriptions',
    license=license,
    packages=find_packages(exclude=('tests', 'docs')),
    install_requires = ['attr','cattrs','logging','functools','typing','math','pytest']
)
